==> eiffelstudio-18.01.10.1424.tar: F_code/C8/gb393.c <==
/*
 * Code for class GB_EV_MENU_ITEM_LIST_ACTION_SEQUENCES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb393.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_EV_MENU_ITEM_LIST_ACTION_SEQUENCES}.names */
static EIF_REFERENCE F657_6505_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("names", 656, Current, 0, 0, 6823);
	RTGC;
	RTOSP (6505);
#define Result RTOSR(6505)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1373,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9928(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("item_select_actions",19,747617907);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(3);
	F431_5905(RTCW(Result));
	RTOSE (6505);
	RTHOOK(4);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F657_6505 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6505,F657_6505_body,(Current));
}

/* {GB_EV_MENU_ITEM_LIST_ACTION_SEQUENCES}.types */
static EIF_REFERENCE F657_6506_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("types", 656, Current, 0, 0, 6824);
	RTGC;
	RTOSP (6506);
#define Result RTOSR(6506)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1373,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9928(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("EV_MENU_ITEM_SELECT_ACTION_SEQUENCE",35,1345777221);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTOSE (6506);
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F657_6506 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6506,F657_6506_body,(Current));
}

/* {GB_EV_MENU_ITEM_LIST_ACTION_SEQUENCES}.comments */
static EIF_REFERENCE F657_6507_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("comments", 656, Current, 0, 0, 6825);
	RTGC;
	RTOSP (6507);
#define Result RTOSR(6507)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1373,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9928(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("-- Actions to be performed when a menu item is selected.",56,1689552686);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTOSE (6507);
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F657_6507 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6507,F657_6507_body,(Current));
}

void EIF_Minit393 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C8/gb393.c <==
/*
 * Code for class GB_EV_CHECKABLE_LIST_ACTION_SEQUENCES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb393.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_EV_CHECKABLE_LIST_ACTION_SEQUENCES}.names */
static EIF_REFERENCE F657_6505_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("names", 656, Current, 0, 0, 6823);
	RTGC;
	RTOSP (6505);
#define Result RTOSR(6505)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1376,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9931(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("check_actions",13,1206144883);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = RTMS_EX_H("uncheck_actions",15,728582259);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(4);
	F431_5905(RTCW(Result));
	RTOSE (6505);
	RTHOOK(5);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F657_6505 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6505,F657_6505_body,(Current));
}

/* {GB_EV_CHECKABLE_LIST_ACTION_SEQUENCES}.types */
static EIF_REFERENCE F657_6506_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("types", 656, Current, 0, 0, 6824);
	RTGC;
	RTOSP (6506);
#define Result RTOSR(6506)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1376,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9931(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("EV_LIST_ITEM_CHECK_ACTION_SEQUENCE",34,465496133);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = RTMS_EX_H("EV_LIST_ITEM_CHECK_ACTION_SEQUENCE",34,465496133);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTOSE (6506);
	RTHOOK(4);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F657_6506 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6506,F657_6506_body,(Current));
}

/* {GB_EV_CHECKABLE_LIST_ACTION_SEQUENCES}.comments */
static EIF_REFERENCE F657_6507_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("comments", 656, Current, 0, 0, 6825);
	RTGC;
	RTOSP (6507);
#define Result RTOSR(6507)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1376,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9931(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("-- Actions to be performed when item is checked.",48,464575534);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = RTMS_EX_H("-- Actions to be performed when item is unchecked.",50,1493716782);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTOSE (6507);
	RTHOOK(4);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F657_6507 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6507,F657_6507_body,(Current));
}

void EIF_Minit393 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
